@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerJs.php,v 1.5 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerJs.php,v 1.6 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerJs.php,v 1.5 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerJs.php,v 1.6 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ControllerJs extends SyL_Controller
@@ -53,7 +53,7 @@ class SyL_ControllerJs extends SyL_Controller
     {
         $config_files = array();
         // Х륳ݡͥե
-        $config_files['components'][] = SYL_WEBAPP_CONFIG_DIR . "/{$this->components_file_name}";
+        $config_files['components'][] = SYL_PROJECT_CONFIG_DIR . "/{$this->components_file_name}";
         // ٥ȼ¹
         $this->raiseEvent('initStream', $config_files);
     }
@@ -72,7 +72,7 @@ class SyL_ControllerJs extends SyL_Controller
             array_shift($config_files['filters']);
         }
         // Хե륿ե
-        $config_files['filters'][] = SYL_WEBAPP_CONFIG_DIR . "/{$this->filter_file_name}";
+        $config_files['filters'][] = SYL_PROJECT_CONFIG_DIR . "/{$this->filter_file_name}";
 
         // ٥ȼ¹
         $this->raiseEvent('loadStream', $config_files);
