@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorJs.php,v 1.4 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorJs.php,v 1.5 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorJs.php,v 1.4 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorJs.php,v 1.5 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorJs extends SyL_Error
@@ -64,7 +64,7 @@ class SyL_ErrorJs extends SyL_Error
 
         // JavaScirptƥĥ
         SyL_Response::setHeader('Content-Type', $content_type);
-        $response =& SyL_Response::getInstance();
+        $response =& SyL_Response::singleton();
         $response->display($error_message);
     }
 
