@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorXmlrpc.php,v 1.2 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorXmlrpc.php,v 1.3 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorXmlrpc.php,v 1.2 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorXmlrpc.php,v 1.3 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorXmlrpc extends SyL_Error
@@ -71,7 +71,7 @@ class SyL_ErrorXmlrpc extends SyL_Error
          // ƥĥ
         $content_type = 'text/xml; charset=' . SYL_ENCODE_XMLRPC;
         SyL_Response::setHeader('Content-Type', $content_type);
-        $response =& SyL_Response::getInstance();
+        $response =& SyL_Response::singleton();
         $response->display($builder->build());
     }
 
