@@ -27,16 +27,11 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestSession.php,v 1.9 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestSession.php,v 1.10 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
-/**
- * ѥץѥƥ饹
- */
-require_once SYL_INCLUDE_DIR . '/lib/Util/SyL_UtilProperty.php';
-
 /**
  * åݻ饹
  * 
@@ -44,7 +39,7 @@ require_once SYL_INCLUDE_DIR . '/lib/Util/SyL_UtilProperty.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestSession.php,v 1.9 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestSession.php,v 1.10 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RequestSession extends SyL_UtilProperty
@@ -64,14 +59,6 @@ class SyL_RequestSession extends SyL_UtilProperty
      */
     var $start = false;
 
-    /**
-     * DBå󥪥֥
-     *
-     * @access private
-     * @var object
-     */
-    var $session_db = null;
-
     /**
      * 󥹥ȥ饯
      *
@@ -88,17 +75,15 @@ class SyL_RequestSession extends SyL_UtilProperty
             if (SYL_SESSION_CACHE) {
                 session_cache_limiter(SYL_SESSION_CACHE);
             }
-
             // åƼѥ᡼
-            $this->path     = SYL_SESSION_PATH   ? SYL_SESSION_PATH   : '/';
-            $session_domain = SYL_SESSION_DOMAIN ? SYL_SESSION_DOMAIN : null;
-            $session_secure = SYL_SESSION_SECURE ? true : false;
+            list($this->path, $session_domain, $session_secure) = explode(':', SYL_SESSION_COOKIE_PARAMS, 3);
+            if (!$this->path) $this->path = '/';
+            if (!$session_domain) $session_domain = null;
+            $session_secure = (bool)$session_secure;
             session_set_cookie_params(0, $this->path, $session_domain, $session_secure);
-
-            if (strtolower(SYL_SESSION_TYPE) == 'db') {
-                // DBå
-                include_once SYL_INCLUDE_DIR . '/framework/RequestParameter/SyL_SessionDB.php';
-                $this->session_db =& new SyL_SessionDB();
+            // å¸ѥ
+            if (SYL_SESSION_SAVE_PATH) {
+                session_save_path(SYL_SESSION_SAVE_PATH);
             }
 
             // å󳫻
