@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ActionForm.php,v 1.1 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ActionForm.php,v 1.2 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/lib/SyL_Form.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ActionForm.php,v 1.1 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ActionForm.php,v 1.2 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ActionForm extends SyL_Form
@@ -113,7 +113,7 @@ class SyL_ActionForm extends SyL_Form
     function &factory($formname, $action='', $callback_parameter=null)
     {
         $formname = ucfirst($formname);
-        include_once SYL_WEBAPP_LIB_DIR . "/forms/{$formname}.php";
+        include_once SYL_PROJECT_LIB_DIR . "/forms/{$formname}.php";
         $form =& new $formname($action, $callback_parameter);
         return $form;
     }
