@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.20 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.21 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.20 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.21 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Container
@@ -327,7 +327,7 @@ echo "</pre>";
     {
         $config = array();
         foreach ($config_type as $type => $file) {
-            $reader =& SyL_Config::getObject($type, $file, $this->getComponent(SYL_CONTROLLER_NAME));
+            $reader =& SyL_Config::factory($type, $file, $this->getComponent(SYL_CONTROLLER_NAME));
             $reader->parseXml();
             $config += $reader->getConfig();
         }
