@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.4 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.5 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -50,7 +50,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Loader.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.4 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.5 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Context
@@ -107,7 +107,7 @@ class SyL_Context
     function SyL_Context(&$controller, &$data)
     {
         $this->controller =& $controller;
-        $this->router     =& SyL_Router::getObject($data, SYL_ROUTER_RULE);
+        $this->router     =& SyL_Router::factory($data, SYL_ROUTER_RULE);
     }
 
     /**
