@@ -27,11 +27,16 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Request.php,v 1.13 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Request.php,v 1.14 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
+/**
+ * ėpvpeBNX
+ */
+require_once SYL_INCLUDE_DIR . '/lib/Util/SyL_UtilProperty.php';
+
 /**
  * XGXgNX
  *
@@ -39,7 +44,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Request.php,v 1.13 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Request.php,v 1.14 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Request
@@ -121,8 +126,15 @@ class SyL_Request
      */
      function createSession()
      {
-         include_once SYL_INCLUDE_DIR . '/framework/Request/SyL_RequestSession.php';
-         $this->session =& new SyL_RequestSession();
+         $type = '';
+         switch (strtolower(SYL_SESSION_TYPE)) {
+         case 'db':       $type = 'Db';       break;
+         case 'memcache': $type = 'Memcache'; break;
+         default:         $type = '';         break;
+         }
+         $classname = "SyL_RequestSession{$type}";
+         include_once SYL_INCLUDE_DIR . "/framework/Request/{$classname}.php";
+         $this->session =& new $classname();
      }
 
     /**
