@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.14 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.15 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.14 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.15 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DB
@@ -166,16 +166,9 @@ class SyL_DB
      * @access public
      * @param string ³ʸ
      */
-    function &getConnection($dsn='', $server_encode='')
+    function &getConnection($dsn, $server_encode='')
     {
         static $singleton = array();
-        if (!$dsn) {
-            if (!count($singleton)) {
-                trigger_error("[SyL error] Dsn not found.", E_USER_ERROR);
-            }
-            return current($singleton);
-        }
-
         if (!isset($singleton[$dsn]) || !is_object($singleton[$dsn])) {
             $tmp  = explode(':', $dsn, 2);
             $type = ucfirst($tmp[0]);
