@@ -3,10 +3,10 @@
  * ȥեݡͥȥ饹
  *
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: C_CreateController.php,v 1.6 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: C_CreateController.php,v 1.7 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class C_CreateController
@@ -25,7 +25,7 @@ class C_CreateController
             $project_dir = substr($project_dir, 0, -1);
         }
 
-        $controller_template = SYL_WEBAPP_DIR . '/var/skel-templates/controller.php';
+        $controller_template = SYL_PROJECT_DIR . '/var/skel-templates/controller.php';
         $contents = file_get_contents($controller_template);
 
         $contents = str_replace('{SYL_DIR}',    SYL_DIR,      $contents);
