@@ -3,10 +3,10 @@
  * ƥץ졼ȥեݡͥȥ饹
  *
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: C_CreateTemplate.php,v 1.6 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: C_CreateTemplate.php,v 1.7 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class C_CreateTemplate
@@ -63,7 +63,7 @@ class C_CreateTemplate
             if (file_exists("{$project_dir}var/skel-templates/template.html")) {
                 copy("{$project_dir}var/skel-templates/template.html", $file);
             } else {
-                copy(SYL_WEBAPP_DIR . '/var/skel-templates/template.html', $file);
+                copy(SYL_PROJECT_DIR . '/var/skel-templates/template.html', $file);
             }
         }
     }
